package main

import (
	"net/http"
	core "nilfm.cc/git/nirvash/archetype"
	shell "nilfm.cc/git/nirvash/lfo"
	"nilfm.cc/git/quartzgun/indentalUserDB"
	"nilfm.cc/git/quartzgun/middleware"
	"nilfm.cc/git/quartzgun/renderer"
	"nilfm.cc/git/quartzgun/router"
	"os"
	"path/filepath"
)

func main() {
	cfg := core.ReadConfig()
	udb := indentalUserDB.CreateIndentalUserDB(
		filepath.Join(
			core.GetConfigLocation(),
			"user.db"))
	if core.ProcessCmd(os.Args, udb, cfg) {
		os.Exit(0)
	}
	if cfg.IsNull() {
		cfg.RunWizard()
	}

	cfg.Adapter.Init(cfg)

	rtr := &router.Router{
		StaticPaths: map[string]string{
			"/static": cfg.AssetRoot,
		},
	}

	rtr.Get("/login",renderer.Template(
		"templates/login.html"))

	rtr.Post("/login", middleware.Authorize("/", udb, "/login?tryagain=1"))

	rtr.Get("/", middleware.Protected(
		shell.WithAdapter(
			renderer.Template(
				"templates/cms_list.html",
				"templates/header.html",
				"templates/footer.html"), cfg.Adapter), http.MethodGet, udb, "/login"))

	rtr.Get(`/edit/(?P<Slug>\S+)`, middleware.Fortify(middleware.Protected(
		shell.WithAdapter(
			renderer.Template(
				"templates/cms_edit.html",
				"templates/header.html",
				"templates/footer.html"), cfg.Adapter), http.MethodGet, udb, "/login")))
				
  rtr.Post(`/save/(?P<Slug>\S+)`, middleware.Defend(middleware.Protected(
    shell.WithAdapter(
      shell.EnsurePageData(
        renderer.Template(
          "templates/cms_save.html",
          "templates/header.html",
          "templates/footer.html")), cfg.Adapter), http.MethodGet, udb, "/login"), udb, "/"))

	http.ListenAndServe(":8080", rtr)
}
